@@ -5,11 +5,12 @@ test_that("importMzXml", {
 
   path <- system.file(file.path("exampledata", "tiny1.mzXML3.0.mzXML"),
                       package="MALDIquantForeign")
-  s <- MALDIquantForeign:::.importMzXml(path)
 
-  expect_equal(s, import(path))
-  expect_equal(s, importMzXml(path))
-  expect_equal(s, import(path, type="mzXML"))
+  s <- MALDIquantForeign:::.importMzXml(path, verbose=FALSE)
+
+  expect_equal(s, import(path, verbose=FALSE))
+  expect_equal(s, importMzXml(path, verbose=FALSE))
+  expect_equal(s, import(path, type="mzXML", verbose=FALSE))
 
   expect_true(isMassSpectrum(s[[1]]))
   expect_equal(mass(s[[1]]), 1:5)
@@ -22,11 +23,12 @@ test_that("importMzXml compressed", {
 
   path <- system.file(file.path("exampledata", "tiny1-compressed.mzXML3.0.mzXML"),
                       package="MALDIquantForeign")
-  s <- MALDIquantForeign:::.importMzXml(path)
 
-  expect_equal(s, import(path))
-  expect_equal(s, importMzXml(path))
-  expect_equal(s, import(path, type="mzXML"))
+  s <- MALDIquantForeign:::.importMzXml(path, verbose=FALSE)
+
+  expect_equal(s, import(path, verbose=FALSE))
+  expect_equal(s, importMzXml(path, verbose=FALSE))
+  expect_equal(s, import(path, type="mzXML", verbose=FALSE))
 
   expect_true(isMassSpectrum(s[[1]]))
   expect_equal(mass(s[[1]]), 1:5)
@@ -40,11 +42,12 @@ test_that("importMzXml centroided", {
 
   path <- system.file(file.path("exampledata", "tiny1-centroided.mzXML3.0.mzXML"),
                       package="MALDIquantForeign")
-  p <- MALDIquantForeign:::.importMzXml(path, centroided=TRUE)
 
-  expect_equal(p, import(path, centroided=TRUE))
-  expect_equal(p, importMzXml(path, centroided=TRUE))
-  expect_equal(p, import(path, type="mzXML", centroided=TRUE))
+  p <- MALDIquantForeign:::.importMzXml(path, centroided=TRUE, verbose=FALSE)
+
+  expect_equal(p, import(path, centroided=TRUE, verbose=FALSE))
+  expect_equal(p, importMzXml(path, centroided=TRUE, verbose=FALSE))
+  expect_equal(p, import(path, type="mzXML", centroided=TRUE, verbose=FALSE))
 
   expect_true(isMassPeaks(p[[1]]))
   expect_equal(mass(p[[1]]), 1:5)
@@ -52,4 +55,3 @@ test_that("importMzXml centroided", {
   expect_equal(basename(metaData(p[[1]])$file),
                "tiny1-centroided.mzXML3.0.mzXML")
 })
-
